# coding: utf-8

"""
    Onshape REST API

    The Onshape REST API consumed by all clients.  # noqa: E501

    OpenAPI spec version: 1.97
    Contact: api-support@onshape.zendesk.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


class BTReleasePackageWorkflowChangeParams(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'workspace_id': 'str',
        'release_package_id': 'str',
        'workflow_state': 'str',
        'is_obsoletion': 'bool',
        'version_id': 'str'
    }

    attribute_map = {
        'workspace_id': 'workspaceId',
        'release_package_id': 'releasePackageId',
        'workflow_state': 'workflowState',
        'is_obsoletion': 'isObsoletion',
        'version_id': 'versionId'
    }

    def __init__(self, workspace_id=None, release_package_id=None, workflow_state=None, is_obsoletion=None, version_id=None):  # noqa: E501
        """BTReleasePackageWorkflowChangeParams - a model defined in OpenAPI"""  # noqa: E501

        self._workspace_id = None
        self._release_package_id = None
        self._workflow_state = None
        self._is_obsoletion = None
        self._version_id = None
        self.discriminator = None

        if workspace_id is not None:
            self.workspace_id = workspace_id
        if release_package_id is not None:
            self.release_package_id = release_package_id
        if workflow_state is not None:
            self.workflow_state = workflow_state
        if is_obsoletion is not None:
            self.is_obsoletion = is_obsoletion
        if version_id is not None:
            self.version_id = version_id

    @property
    def workspace_id(self):
        """Gets the workspace_id of this BTReleasePackageWorkflowChangeParams.  # noqa: E501


        :return: The workspace_id of this BTReleasePackageWorkflowChangeParams.  # noqa: E501
        :rtype: str
        """
        return self._workspace_id

    @workspace_id.setter
    def workspace_id(self, workspace_id):
        """Sets the workspace_id of this BTReleasePackageWorkflowChangeParams.


        :param workspace_id: The workspace_id of this BTReleasePackageWorkflowChangeParams.  # noqa: E501
        :type: str
        """

        self._workspace_id = workspace_id

    @property
    def release_package_id(self):
        """Gets the release_package_id of this BTReleasePackageWorkflowChangeParams.  # noqa: E501


        :return: The release_package_id of this BTReleasePackageWorkflowChangeParams.  # noqa: E501
        :rtype: str
        """
        return self._release_package_id

    @release_package_id.setter
    def release_package_id(self, release_package_id):
        """Sets the release_package_id of this BTReleasePackageWorkflowChangeParams.


        :param release_package_id: The release_package_id of this BTReleasePackageWorkflowChangeParams.  # noqa: E501
        :type: str
        """

        self._release_package_id = release_package_id

    @property
    def workflow_state(self):
        """Gets the workflow_state of this BTReleasePackageWorkflowChangeParams.  # noqa: E501


        :return: The workflow_state of this BTReleasePackageWorkflowChangeParams.  # noqa: E501
        :rtype: str
        """
        return self._workflow_state

    @workflow_state.setter
    def workflow_state(self, workflow_state):
        """Sets the workflow_state of this BTReleasePackageWorkflowChangeParams.


        :param workflow_state: The workflow_state of this BTReleasePackageWorkflowChangeParams.  # noqa: E501
        :type: str
        """

        self._workflow_state = workflow_state

    @property
    def is_obsoletion(self):
        """Gets the is_obsoletion of this BTReleasePackageWorkflowChangeParams.  # noqa: E501


        :return: The is_obsoletion of this BTReleasePackageWorkflowChangeParams.  # noqa: E501
        :rtype: bool
        """
        return self._is_obsoletion

    @is_obsoletion.setter
    def is_obsoletion(self, is_obsoletion):
        """Sets the is_obsoletion of this BTReleasePackageWorkflowChangeParams.


        :param is_obsoletion: The is_obsoletion of this BTReleasePackageWorkflowChangeParams.  # noqa: E501
        :type: bool
        """

        self._is_obsoletion = is_obsoletion

    @property
    def version_id(self):
        """Gets the version_id of this BTReleasePackageWorkflowChangeParams.  # noqa: E501


        :return: The version_id of this BTReleasePackageWorkflowChangeParams.  # noqa: E501
        :rtype: str
        """
        return self._version_id

    @version_id.setter
    def version_id(self, version_id):
        """Sets the version_id of this BTReleasePackageWorkflowChangeParams.


        :param version_id: The version_id of this BTReleasePackageWorkflowChangeParams.  # noqa: E501
        :type: str
        """

        self._version_id = version_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BTReleasePackageWorkflowChangeParams):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
